Welcome to QMLearn!
===================================

Quantum Machine Learning by learning one-body reduced density matrices in the AO basis.

+++++++++++++++++++++
A snapshot of QMLearn
+++++++++++++++++++++

.. image:: /static/figure3.png
  :width: 1000
  :alt: QMLearnOverview

+++++++++++++
In these docs
+++++++++++++

.. toctree::
   :maxdepth: 1

   source/contact
   source/install
   source/tutorials
   source/qmlearn


